<?php

/**
 * @file
 * API documentation for CINC.
 */

/**
 * This is the current target API format for the CINC module.
 *
 * The work being done right now on CINC is in effort to get this file to work.
 * As more work is done, this file and the CINC API may change.
 */

function example_enable() {

  /**
   * Create content types.
   */

  $blog_post = CINC_ContentType::init('example_blog_post', 'Blog Post');
    ->set('description', 'A blog post for writing blogs and what not')

  $event = CINC_ContentType::init('example_event', 'Event');

  $blog_post->create();
  $event->create();

  /**
   * Create fields.
   */

  $subtitle = CINC_FieldText::init($blog_post->machine_name . '_subtitle', 'Subtitle');
  $subtitle->save_to($blog_post);

  $custom_teaser = CINC_FieldLongText::init($blog_post->machine_name . '_teaser', 'Custom Teaser');
  $custom_teaser->save_to($blog_post);

  $related_event = CINC_FieldEntityReference::init($blog_post->machine_name . '_event', 'Related Event');
  $related_event
    ->widget('inline entity')
    ->references($event)
    ->save_to($blog_post);

  $date = CINC_FieldDate::init($event->machine_name . '_date', 'Date');
  $date
    ->widget('pop-up calender')
    ->collect('year')
    ->save_to($event);

}

/**
 * Example YAML representation of the same config above.
 * This needs some settings examples.
 */

content types:
  example_blog_post:
    label: Blog Post
  example_event:
    label: Event
fields:
  example_blog_post_subtitle:
    label: Subtitle
    type: text
    in: [example_blog_post]
  example_blog_post_teaser:
    label: Custom Teaser
    type: long text
    in: [example_blog_post]
  example_blog_post_event:
    label: Related Event
    type: entity reference
    widget: inline entity
    references: [example_event]
    in: [example_blog_post]
  example_event_date:
    label: Date
    widget: pop-up calendar
    collect: year
    in: [example_event]

/**
 * Example Drush interface for adding same config above.
 * Not sure how this should handle nested settings arrays.
 */

$ drush cinc-ct example_blog_post "Blog Post"
$ drush cinc-ct example_event Event
$ drush cinc-f-text example_blog_post_subtitle --label=Subtitle --add-to=example_blog_post
$ drush cinc-f-longtext example_blog_post_teaser --label="Custom Teaser" --add-to=example_blog_post
$ drush cinc-f-entityref example_blog_post_event --label="Related Event" --add-to=example_blog_post
$ drush cinc-f-date example_event_date --label=Date --add-to=example_event


